@@ -69,7 +69,7 @@ def conlog(*args):
     for tx in args:
         text += f"{tx} "
     trc = traceback.extract_stack()[-2]
-    str = f'\033[1;31m {date} \033[0m - \033[4;33m{trc.filename}\033[0m -\033[1;32m {trc.name}|{trc.lineno}\033[0m - {text}'
+    str = f'\033[1;33m {date} \033[0m | \033[4;31m{trc.filename.split("/")[-1]}\033[0m  | \033[1;32m {trc.name} : {trc.lineno}\033[0m  |  {text}'
     print(str)
     return str
 
